| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Data.Type.Witness.Specific.Symbol
Synopsis
- data SymbolType (symbol :: Symbol) where
- MkSymbolType :: forall (symbol :: Symbol). KnownSymbol symbol => SymbolType symbol
- data Symbol
- class KnownSymbol (n :: Symbol)
Documentation
data SymbolType (symbol :: Symbol) where Source #
Constructors
| MkSymbolType :: forall (symbol :: Symbol). KnownSymbol symbol => SymbolType symbol |
Instances
(Kind) This is the kind of type-level symbols.
Instances
| SingKind Symbol | Since: base-4.9.0.0 | ||||
Defined in GHC.Generics Associated Types
| |||||
| TestCoercion SSymbol | Since: base-4.18.0.0 | ||||
Defined in GHC.TypeLits | |||||
| TestEquality SSymbol | Since: base-4.18.0.0 | ||||
Defined in GHC.TypeLits | |||||
| TestEquality SymbolType Source # | |||||
Defined in Data.Type.Witness.Specific.Symbol Methods testEquality :: forall (a :: Symbol) (b :: Symbol). SymbolType a -> SymbolType b -> Maybe (a :~: b) # | |||||
| KnownSymbol a => SingI (a :: Symbol) | Since: base-4.9.0.0 | ||||
Defined in GHC.Generics Methods sing :: Sing a | |||||
| TestOrder SymbolType Source # | |||||
Defined in Data.Type.Witness.Specific.Symbol Methods testCompare :: forall (a :: Symbol) (b :: Symbol). SymbolType a -> SymbolType b -> WOrdering a b Source # | |||||
| Representative SymbolType Source # | |||||
Defined in Data.Type.Witness.Specific.Symbol Methods getRepWitness :: Subrepresentative SymbolType SymbolType Source # | |||||
| WitnessValue SymbolType Source # | |||||
Defined in Data.Type.Witness.Specific.Symbol Associated Types
Methods witnessToValue :: forall (t :: Symbol). SymbolType t -> WitnessValueType SymbolType Source # valueToWitness :: WitnessValueType SymbolType -> (forall (t :: Symbol). SymbolType t -> r) -> r Source # | |||||
| KnownSymbol symbol => Is SymbolType (symbol :: Symbol) Source # | |||||
Defined in Data.Type.Witness.Specific.Symbol Methods representative :: SymbolType symbol Source # | |||||
| AllConstraint Show SymbolType Source # | |||||
Defined in Data.Type.Witness.Specific.Symbol Methods allConstraint :: forall (t :: Symbol). Dict (Show (SymbolType t)) Source # | |||||
| type DemoteRep Symbol | |||||
Defined in GHC.Generics | |||||
| data Sing (s :: Symbol) | |||||
Defined in GHC.Generics | |||||
| type WitnessValueType SymbolType Source # | |||||
Defined in Data.Type.Witness.Specific.Symbol | |||||
| type Compare (a :: Symbol) (b :: Symbol) | |||||
Defined in Data.Type.Ord | |||||
class KnownSymbol (n :: Symbol) #
This class gives the string associated with a type-level symbol. There are instances of the class for every concrete literal: "hello", etc.
Since: base-4.7.0.0
Minimal complete definition